"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createScrollSpyContext = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const useScrollSpy_1 = require("./useScrollSpy");
/**
 * @param ScrollSpyParams Optional params
 * @param ScrollSpyParams.offsetPx Distance from Y coordinate of the base (px)
 * @param ScrollSpyParams.throttleMs Interval of update processing (ms)
 * @returns [ ScrollSpyProvider, useScrollSpyContext ] - Two return values are returned as an array
 * @returns ScrollSpyProvider - This Provider components provides useScrollSpy return value descendants of this Provider
 * @returns useScrollSpyContext - Function is
 */
const createScrollSpyContext = ({ offsetPx = 0, throttleMs = 100, } = {}) => {
    const [activeEntry, actions] = (0, useScrollSpy_1.useScrollSpy)({ offsetPx, throttleMs });
    const ScrollSpyContext = (0, react_1.createContext)({
        activeEntry,
        actions,
    });
    const Provider = ({ children }) => {
        return ((0, jsx_runtime_1.jsx)(ScrollSpyContext.Provider, Object.assign({ value: { activeEntry, actions } }, { children: children }), void 0));
    };
    const getActiveEntry = () => (0, react_1.useContext)(ScrollSpyContext).activeEntry;
    const getActions = () => (0, react_1.useContext)(ScrollSpyContext).actions;
    return { Provider, getActiveEntry, getActions };
};
exports.createScrollSpyContext = createScrollSpyContext;
//# sourceMappingURL=createScrollSpyContext.js.map